package ch.hslu.appe.accounting.webservice;

import java.util.List;

import javax.jws.WebMethod;
import javax.jws.WebService;
import javax.jws.soap.SOAPBinding;
import javax.jws.soap.SOAPBinding.Style;

import ch.hslu.appe.accounting.webservice.Dto.BillDto;

/**
 * Account Service Interface.
 */
@WebService
@SOAPBinding(style = Style.DOCUMENT)
public interface AccountingService {

    /**
     * Gets all bills which belongs to an order.
     * @param orderNumber The order number
     * @return Returns a list of bills
     */
    @WebMethod
    List<BillDto> getOrderBills(int orderNumber);

    /**
     * Gets all bills of a user.
     * @param userId The user id
     * @return Returns a list of bills
     */
    @WebMethod
    List<BillDto> getUserBills(int userId);

    /**
     * Sends a bill.
     * @param orderNumber The order number
     * @param bill The bill
     * @return Returns true on success, otherwise false
     */
    @WebMethod
    boolean sendBill(int orderNumber, BillDto bill);

    /**
     * Updates the state of a bill.
     * @param billId The bill id
     * @param billState The new state
     * @return Returns true on success, otherwise false
     */
    @WebMethod
    boolean updateBillState(int billId, int billState);

    /**
     * Checks whether the user have one or multiple pending dunnings.
     * @param userId The user id
     * @return Returns true if the user have one or more pending dunnings, otherwise false
     */
    @WebMethod
    boolean userHavePendingDunning(int userId);
}
