package ch.hslu.appe.usermanagement.logic;

import java.util.List;

import ch.hslu.appe.usermanagement.filter.UserFilter;
import ch.hslu.appe.usermanagement.model.Address;
import ch.hslu.appe.usermanagement.model.User;

/**
 * Usermanagement Interface.
 */
public interface UserManagement {

    /**
     * Adds a new address entry.
     * @param userId The user id
     * @param address The address
     * @return Returns true on success, otherwise false
     */
    boolean addAddress(int userId, Address address);

    /**
     * Adds a new user.
     * @param user The user
     * @return Returns true on success, otherwise false
     */
    boolean addUser(User user);

    /**
     * Deletes an address by its id.
     * @param addressId The address id
     * @return Returns true on success, otherwise false
     */
    boolean deleteAddress(int addressId);

    /**
     * Deletes a user by its id.
     * @param userId The user id
     * @return Returns true on success, otherwise false
     */
    boolean deleteUser(int userId);

    /**
     * Deletes a user by its login name.
     * @param login The login name
     * @return Returns true on success, otherwise false
     */
    boolean deleteUser(String login);

    /**
     * Gets an address by its id.
     * @param addressId The address id
     * @return Returns the address if it exists, otherwise false
     */
    Address getAddress(int addressId);

    /**
     * Gets all addresses from a user, looked up by its id.
     * @param userId The user id
     * @return Returns all user addresses
     */
    List<Address> getAddresses(int userId);

    /**
     * Gets all addresses of a login.
     * @param login The login name
     * @return Returns all user addresses
     */
    List<Address> getAddresses(String login);

    /**
     * Gets a user by its id.
     * @param id The id
     * @return Returns the user if it exists, otherwise null
     */
    User getUserById(int id);

    /**
     * Gets a user by its login name.
     * @param login The login name
     * @return Returns the user if it exists, otherwise null
     */
    User getUserByLogin(String login);

    /**
     * Gets a list of user which matches to a parameterized filter.
     * @param filter The filter
     * @return Returns all user which matches the filter
     */
    List<User> getUsers(UserFilter filter);

    /**
     * Alters an existent address.
     * @param address The address
     * @return Returns true on success, otherwise false
     */
    boolean updateAddress(Address address);

    /**
     * Alters an existent user.
     * @param user The user
     * @return Returns true on success, otherwise false
     */
    boolean updateUser(User user);
}
