package ch.hslu.appe.usermanagement.session;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertNotEquals;

import java.util.Date;

import org.junit.Before;
import org.junit.Test;

import ch.hslu.appe.usermanagement.exception.IllegalNameException;
import ch.hslu.appe.usermanagement.logic.session.Session;
import ch.hslu.appe.usermanagement.logic.session.SessionManager;
import ch.hslu.appe.usermanagement.model.User;

/**
 * Session Test.
 */
public class SessionTest {

    private User dummyUser;
    private Session session;

    /**
     * JUnit Setup.
     * @throws IllegalNameException Illegal Username
     */
    @Before
    public final void setUp() throws IllegalNameException {

        // Create a dummy user
        dummyUser = new User();
        dummyUser.setLogin("dummy");

        session = SessionManager.getInstance().createSession(dummyUser, 30);
    }

    /**
     * Tests Session Time extending.
     */
    @Test
    public final void testExtend() {

        // Get the valid-until time
        Date validUntil = session.getValidUntil();

        // Extend the session by 30 minutes
        session.extend(30);

        // Add 30 minutes
        validUntil = new Date(validUntil.getTime() + (30 * 60000L));

        // Expected to be the same time
        assertEquals(validUntil.getTime(), session.getValidUntil().getTime());
    }


    /**
     * Test Session GetKey.
     */
    @Test
    public final void testGetKey() {
        assertNotEquals("", session.getKey());
    }


    /**
     * Test GetUser / Username.
     */
    @Test
    public final void testGetUser() {
        assertEquals(dummyUser, session.getUser());
    }

}
